@@ -138,6 +138,7 @@ def create_and_queue_task(data, rule_name: str,
         task = DBTask()
         task.rule = rule
         task.type = task_type
+        task.save()
         # correlate the name of the file with the task
         filename = '{0}.dat'.format(task.name)
         if isinstance(data, str):
@@ -151,7 +152,6 @@ def create_and_queue_task(data, rule_name: str,
         except IntegrityError:
             logger.warning('There was a task name conflict trying to generate '
                            'a new one...')
-            task.name = haikunate()
             task.save()
         for task_parameter in task_parameters:
             task_parameter.task = task
@@ -166,6 +166,7 @@ def create_and_queue_task(data, rule_name: str,
         return task
     except IntegrityError:
         logger.exception('There was an error creating and queuing the task.')
+        raise
     except DBRule.DoesNotExist:
         raise RuleNotFound(
             _('The Rule with name %s could not be found.  Please check '
